/*
 * レーダーチャートのサンプルプログラム
 * Copyright (c) 2015 Cybozu
 *
 * Licensed under the MIT License
 */

(function() {
    "use strict";

    // レコード追加、編集時のイベント
    var eventsCreateShow = ['app.record.create.show', 'app.record.edit.show',
                            'app.record.index.create.show', 'app.record.index.edit.show'];
    kintone.events.on(eventsCreateShow, function(event) {
        // グループフィールドの"Chart"を非表示にする
        kintone.app.record.setFieldShown('Chart', false);

    });

    // レコード詳細表示時にチャートを表示する（PC、スマートフォン両対応）
    var eventsDetailShow = ['app.record.detail.show', 'mobile.app.record.detail.show'];
    kintone.events.on(eventsDetailShow, function(event) {

        var record = event.record;
        var data = {
            labels: ["国語", "数学", "英語", "社会", "理科"],
            datasets: [
                {
                    label: "My First dataset",
                    fillColor: "rgba(0,140,232,.4)",
                    strokeColor: "rgba(151,187,205,1)",
                    pointColor: "rgba(151,187,205,1)",
                    pointStrokeColor: "#fff",
                    data: [
                        record['Japanese']['value'],
                        record['Mathematics']['value'],
                        record['English']['value'],
                        record['Social_studies']['value'],
                        record['Science']['value']
                    ]
                }
            ]
        };

        // Chart.js のオプションを設定する
        var options = {
            scaleShowLine: true,
            angleShowLineOut: true,
            scaleShowLabels: true,
            scaleBeginAtZero: true,
            angleLineColor: "rgba(0,0,0,.1)",
            angleLineWidth: 1,
            pointLabelFontFamily: "'Arial'",
            pointLabelFontStyle: "normal",
            pointLabelFontSize: 16,
            pointLabelFontColor: "#666",
            pointDot: true,
            pointDotRadius: 5,
            pointDotStrokeWidth: 1,
            pointHitDetectionRadius: 20,
            datasetStroke: true,
            datasetStrokeWidth: 3,
            datasetFill: true,
            responsive: true
        };

        var elRadar;
        var elCanvas = document.createElement('canvas');
        elCanvas.id = 'canvas';

        // スペースフィールドにレーダーチャートを表示する（スマートフォン用にも対応させる）
        // PC用、スマートフォン表示時でサイズを調整する
        if (event.type === 'mobile.app.record.detail.show') {
            elRadar = kintone.mobile.app.getHeaderSpaceElement();
            elCanvas.style.position = 'relative';
            elCanvas.style.top = '10px';
            elCanvas.style.left = '10px';
            elCanvas.height = '300';
            elCanvas.width = '300';
        } else {
            elRadar = kintone.app.record.getSpaceElement('Radar');
            elCanvas.height = '400';
            elCanvas.width = '400';
        }

        elRadar.appendChild(elCanvas);
        var myChart = new Chart(elCanvas.getContext("2d")).Radar(data, options);

    });
})();
